@@ -1,6 +1,7 @@
 from ape import plugins
 
 from .explorer import Etherscan
+from .query import EtherscanQueryEngine
 
 NETWORKS = {
     "ethereum": [
@@ -25,6 +26,7 @@ NETWORKS = {
     ],
     "avalanche": [
         "mainnet",
+        "fuji",
     ],
     "bsc": [
         "mainnet",
@@ -39,3 +41,8 @@ def explorers():
         for network_name in NETWORKS[ecosystem_name]:
             yield ecosystem_name, network_name, Etherscan
             yield ecosystem_name, f"{network_name}-fork", Etherscan
+
+
+@plugins.register(plugins.QueryPlugin)
+def query_engines():
+    yield EtherscanQueryEngine
