@@ -1,6 +1,7 @@
 from typing import Callable
 
 import pytest
+from ape.api.query import AccountTransactionQuery
 
 from ape_etherscan import NETWORKS
 from ape_etherscan.exceptions import EtherscanResponseError, EtherscanTooManyRequestsError
@@ -39,8 +40,8 @@ base_url_test = pytest.mark.parametrize(
         ("arbitrum", "goerli-fork", "goerli.arbiscan.io"),
         ("optimism", "mainnet", "optimistic.etherscan.io"),
         ("optimism", "mainnet-fork", "optimistic.etherscan.io"),
-        ("optimism", "goerli", "goerli-optimistic.etherscan.io"),
-        ("optimism", "goerli-fork", "goerli-optimistic.etherscan.io"),
+        ("optimism", "goerli", "goerli-optimism.etherscan.io"),
+        ("optimism", "goerli-fork", "goerli-optimism.etherscan.io"),
         ("polygon", "mainnet", "polygonscan.com"),
         ("polygon", "mainnet-fork", "polygonscan.com"),
         ("polygon", "mumbai", "mumbai.polygonscan.com"),
@@ -76,9 +77,11 @@ def verification_tester_cls():
 
 
 @pytest.fixture
-def setup_verification_test(mock_backend, verification_params, verification_tester_cls):
+def setup_verification_test(
+    mock_backend, verification_params, verification_tester_cls, address_to_verify
+):
     def setup(found_handler: Callable, threshold: int = 2):
-        mock_backend.setup_mock_account_transactions_response()
+        mock_backend.setup_mock_account_transactions_response(address=address_to_verify)
         mock_backend.add_handler("POST", "contract", verification_params, return_value=PUBLISH_GUID)
         verification_tester = verification_tester_cls(found_handler, threshold=threshold)
         mock_backend.add_handler(
@@ -144,9 +147,12 @@ def test_get_contract_type_additional_types(mock_backend, file_name, explorer):
     assert actual == expected
 
 
-def test_get_account_transactions(mock_backend, explorer, address):
-    mock_backend.setup_mock_account_transactions_response()
-    actual = [r for r in explorer.get_account_transactions(address)][0].txn_hash
+def test_get_account_transactions(mock_backend, account):
+    mock_backend.setup_mock_account_transactions_response(account.address)
+    query = AccountTransactionQuery(
+        start_nonce=0, stop_nonce=0, columns=["txn_hash"], account=account.address
+    )
+    actual = next(account.query_manager.engines["etherscan"].perform_query(query)).txn_hash
     expected = "0x5780b43d819035ed1fa079171bdce7f0bbeaa6b01f201f8985d279a66cfc6844"
     assert actual == expected
 
@@ -162,6 +168,7 @@ def test_publish_contract(
     setup_verification_test,
     expected_verification_log,
     caplog,
+    fake_connection,
 ):
     setup_verification_test(lambda: "Pass - You made it!")
     explorer.publish_contract(address_to_verify)
